#!/bin/bash
echo "Set up and run a LDOS calculation + grid2cube after PDOS calc"
echo "Written by Svante Hedstrom"
PDOSLABEL=${1%.fdf}
SYSLABEL=${PDOSLABEL%PDOS}
ENERGY=$2
EMIN=$(echo $ENERGY"-0.01" | bc)
EMAX=$(echo $ENERGY"+0.01" | bc)
EHUND=$(echo "scale=0; ($ENERGY*1000)/1" | bc)
if [ ! -e $SYSLABEL"PDOS.fdf" ]
then
  if [ ! -e $SYSLABEL".fdf" ]
    then
    echo "No PDOSfdf-file found with specified label. Usage: LDOSsubmit.sh SystemLabel[PDOS][.fdf] StateEnergy"
    exit
  fi
fi

#Filenames and paths
if [ -e $SYSLABEL"PDOS.fdf" ]
then
  PDOSFDF=$SYSLABEL"PDOS.fdf"
else
  PDOSFDF=$SYSLABEL.fdf
fi
LDOSNAME=$SYSLABEL"L"$EHUND
LDOSFDF=$LDOSNAME.fdf

#Copy DM file if exists to avoid having to rerun siesta
if [ -e "$SYSLABEL"PDOS.DM ]
  then
  cp "$SYSLABEL"PDOS.DM $LDOSNAME.DM
else
  cp "$SYSLABEL".DM $LDOSNAME.DM
fi


#Make the appropriate edits to the fdf inputfile
  sed -e 's/ProjectedDensityOfStates/LocalDensityOfStates/' $PDOSFDF > $LDOSFDF
  sed -i "s/"$SYSLABEL"PDOS/$LDOSNAME/" $LDOSFDF
  sed -i 's/-8.00 0.00 0.010 8001 eV/ '$EMIN' '$EMAX' eV/' $LDOSFDF
  

#Prepare the qsub submission script
sed -e "s/FILENAME/"$LDOSNAME"/g" ~/TranSiestaJobs/CommonFiles/LDOSqsub.sh >$LDOSNAME
if [ ! -e "$SYSLABEL"PDOS.DM ] 
  then
  sed -i 's/00:14/00:55/g' $LDOSNAME
fi

#Prepare the grid2cube input file
echo $LDOSNAME > $LDOSNAME.gridin
echo ldos >> $LDOSNAME.gridin
echo "15.0 15.0 0.5" >> $LDOSNAME.gridin
echo 1 >> $LDOSNAME.gridin
echo "unformatted" >> $LDOSNAME.gridin
echo "" >> $LDOSNAME.gridin

#Submit the job which will do both Siesta LDOS and grid2cube
bsub < $LDOSNAME  
