!*************************************************************
! A program to extract the coordinates form the xyz file  
! to build a FEFF input
!************************************************************

program xyztofdf

	
	implicit none

	integer, parameter :: dp = kind(1.0d0)

	character(5) :: string
	integer :: i,atoms, count, index, Natoms,Nsp,spz(1000),N,j,k,posible_atom
	integer, allocatable :: atom_number(:),species(:), sp(:)
  real(dp) :: x,y,z,lmax,lmax_1,lmin,period
  real(dp), allocatable :: r(:,:)
	character(2), allocatable :: atom_type(:),sp_name(:)
  character(1) :: type_of_input


!-------------------------------------------------!     
!      Periodic table					          !
!-------------------------------------------------!   
   integer, parameter :: NZ = 103 

   character(len=2), parameter :: NAME(NZ) = &
             (/'H ','He','Li','Be','B ','C ','N ','O ','F ','Ne', &
               'Na','Mg','Al','Si','P ','S ','Cl','Ar','K ','Ca', &
               'Sc','Ti','V ','Cr','Mn','Fe','Co','Ni','Cu','Zn', &
               'Ga','Ge','As','Se','Br','Kr','Rb','Sr','Y ','Zr', &
               'Nb','Mo','Tc','Ru','Rh','Pd','Ag','Cd','In','Sn', &
               'Sb','Te','I ','Xe','Cs','Ba','La','Ce','Pr','Nd', &
               'Pm','Sm','Eu','Gd','Tb','Dy','Ho','Er','Tm','Yb', &
               'Lu','Hf','Ta','W ','Re','Os','Ir','Pt','Au','Hg', &
               'Tl','Pb','Bi','Po','At','Rn','Fr','Ra','Ac','Th', &
               'Pa','U ','Np','Pu','Am','Cm','Bk','Cf','Es','Fm', &
               'Md','No','Lr'/)


	open(unit=1,file='coords.xyz',status='old',action='read')
	open(unit=2,file='coords.fdf')
	
!Counts the number of atoms
	read(1,*)Natoms
  read(1,*)

	allocate(r(Natoms,3))
	allocate(atom_type(Natoms))
	allocate(atom_number(Natoms))
  allocate(species(Natoms))
  allocate(sp(Natoms))
  allocate(sp_name(Natoms))


  do i=1,Natoms
      read(1,*)atom_type(i), r(i,1), r(i,2), r(i,3)
!       write(*,*)atom_type(i), r(i,1), r(i,2), r(i,3)
  enddo

  do i=1,Natoms
    do j=1,NZ
      if(atom_type(i).EQ.name(j)) atom_number(i)=j
    enddo
  enddo	

  species(1)=atom_number(1)
  sp_name(1)=atom_type(1)
  nsp=1
  count=0

    do i=1,Natoms
      do j=1,nsp
        if(atom_number(i).NE.species(j).and.species(j).NE.0)then
				posible_atom=atom_number(i)
				count=count+1
				endif
      enddo
      if(count.EQ.nsp)then
        nsp=nsp+1
				species(nsp)=posible_atom
				sp_name(nsp)=NAME(posible_atom)
      endif
      count = 0
    enddo
 
! Here we asing an specie number 1,2,3 ...
 
  do i=1,Natoms 
    do j=1,nsp
        if(atom_number(i).EQ.species(j)) sp(i)=j
      enddo	
!       write(*,*)sp(i)
    enddo

! 		do i=1,Nsp
! 			write(*,*)species(i),sp_name(i)
!  	  enddo


	write(*,*)'########################################################'
	write(*,*)'#    Default input for running  TS calulations     '
	write(*,*)'#  Written by C.F.A. Negre, Yale University, Chem. Dep. '	
	write(*,*)'########################################################'  
	write(*,*)''
	write(*,*)'Select the type of input: (1)Leads, (2)Molecule '
	read(*,*)type_of_input
	write(*,*)''
	write(*,*)'Calculating periodicity ...'
  
	lmax=-1000.0
	lmin=1000.0
	lmax_1=-1000.0

		do i=1,Natoms
			if(r(i,3).GT.lmax)lmax=r(i,3)
			if(r(i,3).LT.lmin)lmin=r(i,3)
 	  enddo

		do i=1,Natoms
			if(r(i,3).GT.lmax_1.and.r(i,3).LT.lmax)lmax_1=r(i,3)
 	  enddo

		period=lmax-lmin+lmax-lmax_1
!     write(*,*)lmax,lmin,lmax_1

!Default header for TS run....
	write(2,*)'########################################################'
	write(2,*)'#    Default input for running  TS calulations     '
	write(2,*)'#  Written by C.F.A. Negre, Yale University, Chem. Dep. '
	write(2,*)'########################################################'  
	write(2,*)''
	if(type_of_input.EQ.'1')then
		write(2,*)'SystemName       Transport  # This has to be always Transport for TRANSIESTA'
		write(2,*)'SystemLabel      Lead    # Short name for naming files'
	else
		write(2,*)'SystemName       Transport  # Descriptive name of the system'
		write(2,*)'SystemLabel      Mol    # Short name for naming files'
	endif
  write(2,*)' '
  write(2,*)'# SPECIES AND BASIS '
  write(2,*)' '
  write(2,*)'NumberOfAtoms ',Natoms   
  write(2,*)'NumberOfSpecies',nsp
  write(2,*)' '
  write(2,*)'LatticeConstant         1.0000 Ang'
  write(2,*)'%block LatticeVectors'
  write(2,*)'    30.000    0.000    0.00000'
  write(2,*)'    0.000    30.000    0.00000'
  write(2,'(a22,3f10.5)')'    0.00000    0.00000',period
  write(2,*)'%endblock LatticeVectors'
	write(2,*)''
	write(2,*)'#--BASIS SET'
  write(2,*)' '
	write(2,*)'PAO.BasisType split '
	write(2,*)'PAO.SplitNorm 0.15'
	write(2,*)'# PAO.BasisSize DZP     #This flag sets the same basis set for all atoms'
	write(2,*)'%block    PAO.BasisSizes'
	do i=1,nsp
		write(2,*)'    ',sp_name(i),'  DZ'
	enddo
	write(2,*)'%endblock  PAO.BasisSizes'
	write(2,*)'PAO.EnergyShift 0.01 eV'
	write(2,*)''
	write(2,*)'# K-POINTS'
  write(2,*)' '
	write(2,*)'%block kgrid_Monkhorst_Pack'
  write(2,*)'    1   0   0    0.0'
  write(2,*)'    0   1   0    0.0'
  write(2,*)'    0   0  80    0.5		#change to 0   0  1    0.0'
	write(2,*)'%endblock kgrid_Monkhorst_Pack'
	write(2,*)'BandLinesScale          ReciprocalLatticeVectors'
	write(2,*)''
	write(2,*)'# GENERAL VARIABLES'
  write(2,*)' '
	write(2,*)'#--Exchange-correlation functionals'
	write(2,*)'XC.functional         GGA    # LDA or GGA'                                  
	write(2,*)'XC.authors            PBE   # CA = PZ, PW92, PBE'          
	write(2,*)'MeshCutoff  200.0 Ry'
	write(2,*)''
	write(2,*)'# SPIN OPTIONS'
  write(2,*)' '
	write(2,*)'#SpinPolarized                   F               # T, F'
	write(2,*)'#FixSpin                         F '
	write(2,*)'#TotalSpin                       0.0'
	write(2,*)'#NonCollinearSpin                F               # T, F'
	write(2,*)''
	write(2,*)'# SCF OPTIONS'
  write(2,*)' '
	write(2,*)'ElectronicTemperature           300 K'         
	write(2,*)'MaxSCFIterations                30000'	
	write(2,*)'DM.MixingWeight                 0.02'
	write(2,*)'DM.NumberPulay                  4          # Pulay convergency accelerator'
	write(2,*)'#DM.MixSCF1                      T'	
	write(2,*)'#DM.MixH                         T'	
	write(2,*)'#DM.PulayOnFile                  F       # Store in memory (F) or in files (T)'
	write(2,*)'DM.Tolerance                    1.0D-5'
	write(2,*)'DM.UseSaveDM                    T'
	write(2,*)''
	write(2,*)'# TRANSPORT VARIABLES'
  write(2,*)' '
	if(type_of_input.EQ.'1')then
  write(2,*)' '
	else
	write(2,*)'SolutionMethod                  transiesta'
  write(2,*)' '
	write(2,*)'#-- ELECTRODES'
	write(2,*)'TS.HSFileLeft   Lead.TSHS'
	write(2,*)'TS.NumUsedAtomsLeft   ***'
	write(2,*)'TS.HSFileRight  Lead.TSHS'
	write(2,*)'TS.NumUsedAtomsRight  ***'
	write(2,*)''
	write(2,*)'#--TRANSPORT BLOCK'
	write(2,*)'TS.TBT.NPoints        1000'
	write(2,*)'TS.TBT.Emin           -1.0 eV'
	write(2,*)'TS.TBT.Emax             1.0 eV'
	write(2,*)'TS.TBT.OutputRegionData False'
	write(2,*)'TS.BiasContour.NumPoints 100'
	write(2,*)'TS.ComplexContour.Emin  -20.0 Ry'
	write(2,*)'TS.ComplexContour.NumCircle 100'
	write(2,*)'TS.ComplexContour.NumLine  20'
	write(2,*)'TS.ComplexContour.NumPoles 10'
	write(2,*)'TS.BiasContour.Eta 10D-4  Ry'
	write(2,*)'TS.Voltage VOLTAGE  eV'
	endif
	write(2,*)''
	write(2,*)'# SYSTEM'
  write(2,*)' '
	write(2,*)'%block ChemicalSpeciesLabel'
	do i=1,nsp
		write(2,*) i, species(i), sp_name(i),  '    # Species index, atomic number, species label'
	enddo
	write(2,*)'%endblock ChemicalSpeciesLabel'
	write(2,*)' '
	write(2,*)'AtomicCoordinatesFormat  Ang'
  write(2,*)'%block AtomicCoordinatesAndAtomicSpecies'
	do i=1,Natoms	
		write(2,'(3f10.5,I2,a)') r(i,1), r(i,2), r(i,3), sp(i)
	enddo 
	write(2,*)'%endblock AtomicCoordinatesAndAtomicSpecies'
  write(2,*)''

end


  
